/*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements.  The ASF licenses this file to You
* under the Apache License, Version 2.0 (the "License"); you may not
* use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.  For additional information regarding
* copyright in this work, please see the NOTICE file in the top level
* directory of this distribution.
*/
package org.apache.abdera.protocol.server.servlet;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.abdera.protocol.server.util.ServerUtils;
import org.apache.abdera.util.CompressionUtil;
import org.apache.abdera.util.CompressionUtil.CompressionCodec;

/**
 * A filter that applies either GZip or Compress encoding on a response
 * depending on the value of the Accept-Encoding request header.
 * 
 * Note: This is currently untested
 */
public class CompressionFilter
  extends AbstractFilter
  implements Filter {

  public void doFilter(
    ServletRequest request, 
    ServletResponse response,
    FilterChain chain) 
      throws IOException, ServletException {
    
    HttpServletRequest req = (HttpServletRequest) request;
    String encoding = req.getHeader("Accept-Encoding");
    String[] encodings = 
      encoding != null ? 
        ServerUtils.orderByQ(encoding) : 
        new String[0];
    for (String enc : encodings) {
      if (CompressingResponseWrapper.canHandle(enc)) {
        CompressionCodec codec = CompressionUtil.getCodec(enc);
        CompressingResponseWrapper resp = 
          new CompressingResponseWrapper(
            (HttpServletResponse) response, codec);
        chain.doFilter(request, response);
        resp.finish();
        return;
      }
    }
    chain.doFilter(request, response);
  }

}
